@@ -1,7 +1,7 @@
 # Responder usage example
 
 
-from responder import ResponderGroup, ResponderCustom, ResponderStatic
+from responder import ResponderGroup, ResponderCustom, ResponderStatic, ResponderFlashing
 import tinytuya
 import firebase_admin
 from firebase_admin import credentials, db
@@ -19,7 +19,7 @@ default_app = firebase_admin.initialize_app(cred, {
 
 def main():
     rc = ResponderGroup(0, 1)
-    rc.add(ResponderFlashingDevice("1", sw1.turn_on, sw1.turn_off, 2000, 500, 2))
+    rc.add(ResponderFlashing("1", sw1.turn_on, sw1.turn_off, 2000, 500, 2))
     rc.add(ResponderCustom(3, 2, [led1.turn_on, led1.set_colour, led1.set_colour], [500, 500, 500],
                                  [None, [255, 0, 0], [0, 0, 30]]))
 
